@@ -1,30 +1,31 @@
-
-# This file was created by mkconfig.rb when ruby was built.  Any
-# changes made to this file will be lost the next time ruby is built.
+# frozen-string-literal: false
+# This file was created by mkconfig.rb when ruby was built.  It contains
+# build information for ruby which is used e.g. by mkmf to build
+# compatible native extensions.  Any changes made to this file will be
+# lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("2.2.4"[/^[0-9]+[.][0-9]+[.]/]) or
-    raise "ruby lib version (2.2.4) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.3.") or
+    raise "ruby lib version (2.3.0) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.2.0/armv7l-linux-eabihf")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.3.0/armv7l-linux-eabihf")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "2"
+  CONFIG["MINOR"] = "3"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "230"
+  CONFIG["PATCHLEVEL"] = "0"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)"
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME)"
-  CONFIG["DESTDIR"] = ""
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.2.pc"
+  CONFIG["ruby_pc"] = "ruby-2.3.pc"
   CONFIG["PACKAGE"] = "ruby"
-  CONFIG["BUILTIN_TRANSSRCS"] = " newline.c"
+  CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
   CONFIG["USE_RUBYGEMS"] = "YES"
   CONFIG["MANTYPE"] = "doc"
   CONFIG["NROFF"] = "/usr/bin/nroff"
@@ -38,6 +39,7 @@ module RbConfig
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
   CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O2 -pipe -fstack-protector --param=ssp-buffer-size=4' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2' 'CXXFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O2 -pipe -fstack-protector --param=ssp-buffer-size=4'"
+  CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
   CONFIG["vendordir"] = "$(rubylibprefix)/vendor_ruby"
@@ -46,7 +48,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.2.0"
+  CONFIG["ruby_version"] = "2.3.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "armv7l-linux-eabihf"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -85,27 +87,16 @@ module RbConfig
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = "-std=iso9899:1999"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations -Wno-packed-bitfield-compat"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations -Wno-packed-bitfield-compat -Wno-maybe-uninitialized"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
-  CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
-  CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
-  CONFIG["cppflags"] = ""
   CONFIG["NULLCMD"] = ":"
   CONFIG["DLNOBJ"] = "dln.o"
-  CONFIG["INSTALLDOC"] = "all"
-  CONFIG["CAPITARGET"] = "nodoc"
-  CONFIG["RDOCTARGET"] = "rdoc"
-  CONFIG["DTRACE_REBUILD"] = ""
-  CONFIG["DTRACE_OBJ"] = ""
-  CONFIG["DTRACE_EXT"] = "dmyh"
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
   CONFIG["EXTOUT"] = ".ext"
-  CONFIG["RUNRUBY_COMMAND"] = "$(MINIRUBY) $(srcdir)/tool/runruby.rb --extout=$(EXTOUT) $(RUNRUBYOPT)"
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
-  CONFIG["BTESTRUBY"] = "$(MINIRUBY)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
   CONFIG["rubylibprefix"] = "$(libdir)/$(RUBY_BASE_NAME)"
@@ -114,6 +105,7 @@ module RbConfig
   CONFIG["EXTSTATIC"] = ""
   CONFIG["STRIP"] = "strip -S -x"
   CONFIG["TRY_LINK"] = ""
+  CONFIG["PRELOADENV"] = "LD_PRELOAD"
   CONFIG["LIBPATHENV"] = "LD_LIBRARY_PATH"
   CONFIG["RPATHFLAG"] = ""
   CONFIG["LIBPATHFLAG"] = " -L%s"
@@ -142,7 +134,6 @@ module RbConfig
   CONFIG["PYTHON"] = ""
   CONFIG["DOXYGEN"] = "doxygen"
   CONFIG["DOT"] = "dot"
-  CONFIG["DTRACE"] = ""
   CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
   CONFIG["MKDIR_P"] = "/usr/bin/mkdir -p"
   CONFIG["INSTALL_DATA"] = "$(INSTALL) -m 644"
@@ -196,8 +187,10 @@ module RbConfig
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "armv7l"
   CONFIG["build"] = "armv7l-unknown-linux-gnueabihf"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.2.4"
-  CONFIG["HAVE_BASERUBY"] = "no"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.3.0"
+  CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cppflags"] = ""
+  CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
